<template>
  <div class="rightContent">
    <div class="top">
      <SearchCommonView
        :add-title="addTitle"
        :show-discard="showDiscard"
        :show-apply="false"
        :placeholder="'请输入位置/产品'"
        :amount-view="false"
        @addCommonClick="addProductClick"
        @searchClick="getList"
        @discardBtnClick="discardBtnClick"
        @applyBtnClick="applyBtnClick"
      />
    </div>
    <div class="list-view">
      <div class="table">
        <CommonFormTableView
          ref="tablelistRef"
          :isOperateAdd="false"
          :product-table-list="tableList"
          @inputContent="inputContent"
          @selLocationClick="selLocationClick"
          @selProductClick="selProductClick"
          @tableRowClick="tableRowClick"
        >
          <template slot="tableButton">
            <el-table-column label="操作" width="180" align="center">
              <template slot-scope="scope">
                <span v-if="scope.row.isEdit" @click.stop="handleHistoryClick(scope.row)" class="yes-cursor">
                  <i class="el-icon-refresh-left"></i>
                  <span>历史</span>
                </span>
                <!-- <span v-if="scope.row.isSet" @click="handleSetClick(scope)" class="margin_left_5px">
                  <i class="el-icon-setting"></i>
                  <span>设置</span>
                </span> -->
                <template v-if="scope.row.status === 3">
                  <span @click.stop="handleUseClick(scope.row)" class="margin_left_5px">
                    <i class="el-icon-document"></i>
                    <span>应用</span>
                  </span>
                  <!-- <span @click="handleCleanupClick(scope)" class="margin_left_5px">
                    <i class="el-icon-delete"></i>
                    <span>清除</span>
                  </span> -->
                </template>
              </template>
            </el-table-column>
          </template>
        </CommonFormTableView>
      </div>
      <div class="btn-pager">
        <PagerView class="page" :pager-options="pagerOptions" v-on="pagerEvents" />
      </div>
    </div>
  </div>
</template>

<script>
import CommonFormTableView from "@/components/makepager/CommonFormTableView"
import pageMixin from "@/components/makepager/pager/mixin/pageMixin"
import {
  getInventoryAdjustmentList,
  addInventoryAdjustment,
  updateInventoryAdjustment,
  finishInventoryAdjustment,
  getLocationProductAmount
} from "@/api/operate/inventoryAdjustment"
import { currentTime } from "@/common/config/index"

export default {
  name: "InventoryAdjustment",
  props: {},
  components: { CommonFormTableView },
  mixins: [pageMixin],
  computed: {},
  data() {
    return {
      addTitle: "新建",
      showDiscard: false,
      tableList: {},
      tableData: [],
      searchOptions: [],
      countId: 0,
      isNoProduct: true, // 添加明细行时是否有产品未选择
      isRowClick: false,
      locationId: 0,
      productId: 0,
      differenceAmount: 0,
      amount: 0,
      operationId: 0,
      adjustAmount: 0
    }
  },
  created() {
    this.setTable()
    this.getData()
  },
  methods: {
    setTable() {
      this.tableList = {
        tableData: this.tableData,
        selectBox: false,
        selectIndex: true,
        tableColumn: [
          { label: "位置", prop: "locationName", location: true },
          { label: "产品", prop: "productName", product: true },
          { label: "在库数量", prop: "amount" },
          { label: "计量单位", prop: "unit" },
          { label: "计数的数量", prop: "differenceAmount", inputFloat: true },
          { label: "差异", prop: "adjustAmount" },
          { label: "日期", prop: "createDate" },
          { label: "用户", prop: "user", user: true }
        ]
      }
    },
    // 请求数据
    async getData() {
      await getInventoryAdjustmentList({
        page: this.pagerOptions.currPage,
        pageSize: this.pagerOptions.pageSize
      }).then((res) => {
        if (res.code === 200) {
          console.log(res)
          const list = res.data.map((item) => {
            item.adjustAmount = 0
            return {
              ...item,
              isSet: false,
              isEdit: true,
              editable: true,
              adjustAmount: 0
            }
          })
          this.tableList.tableData = list || []
          this.tableData = list || []
          this.pagerOptions.totalCount = res.total
        }
      })
      
    },
    // 操作输入
    inputContent(val, prop, row) {
      console.log(val, prop, row)
      console.log(val - row.amount, "结果")
      this.adjustAmount = val - row.amount
      this.tableList.tableData[row.index].adjustAmount = this.adjustAmount
      // this.differenceAmount = val
      this.differenceAmount = val
    },
    // 新增
    addProductClick() {
      console.log(this.tableData)
      console.log(this.addTitle)
      this.isSel()
      if (this.isNoProduct && this.addTitle === "新建") {
        this.$refs.tablelistRef.getLocationList()
        this.addTitle = "保存"
        this.showDiscard = true
        this.isRowClick = false
        this.operationId = 0
        this.currentRowId = 0
        this.countId++
        this.tableData.unshift({
          countId: this.countId,
          amount: 0,
          adjustAmount: 0,
          productId: "",
          differenceAmount: 0,
          locationId: 0,
          createDate: this.currentTime(),
          isSet: true,
          isEdit: false,
          editable: false
        })
        this.locationId = 0
        this.subLocationId = 0
        this.productCategoryId = 0
        this.productId = 0
      } else {
        this.addTitle = "新建"
        this.showDiscard = false
        let requestUrl = this.currentRowId === 0 ? addInventoryAdjustment : updateInventoryAdjustment

        requestUrl({
          amount: this.amount,
          // adjustAmount: this.adjustAmount,
          differenceAmount: this.differenceAmount,
          locationId: this.locationId,
          operationId: this.operationId,
          productId: this.productId
        })
          .then((res) => {
            console.log(res)
            if (res.code === 200) {
              let tipStr = this.currentRowId === 0 ? "添加成功" : "修改成功"
              this.$message.success(tipStr)
              this.getData()
            }
          })
          .catch((err) => {
            console.log(err)
            this.getData()
          })
        // }
      }
    },
    // 是否选择产品
    isSel() {
      for (let i = 0; i < this.tableData.length; i++) {
        // this.tableData[i].productName?.length === 0||!this.tableData[i].productId
        if (!this.tableData[i].productId||!this.tableData[i].isEdit) {
          this.isNoProduct = false
          break
        } else {
          this.isNoProduct = true
        }
      }
    },
    // 取消
    discardBtnClick() {
      this.getData()
      // this.tableList.tableData.forEach((item) => {
      //   item.differenceAmount = 0
      //   item.adjustAmount = 0
      // })
      // this.tableList
      // if (this.isRowClick) {
      //   this.tableData.map((item) => {
      //     item.isEdit = true
      //   })
      // } else {
      //   this.tableData.splice(0, 1)
      // }
      this.addTitle = "新建"
      this.showDiscard = false
    },
    // 应用全部
    applyBtnClick() {
      console.log("应用全部")
    },
    // 历史
    handleHistoryClick(row) {
      this.isSel()
      console.log(row)
      if (this.isNoProduct) {
        this.$router.push({
          name: "inventoryAdjustmentHistory",
          params: { locationId: row.locationId, productId: row.productId, baseOperationType: row.baseOperationType }
        })
      }
    },
    // 设置
    handleSetClick(scope) {
      this.isSel()
      if (this.isNoProduct) {
        scope.row.isSet = !scope.row.isSet
      }
    },
    // 应用
    handleUseClick(row) {
      // scope.row.isSet = !scope.row.isSet
      finishInventoryAdjustment({
        locationProductAmountId: row.locationProductAmountId,
        operationId: row.operationId,
        productId: row.productId
      }).then((res) => {
        console.log(res)
        if (res.code === 200) {
          this.$message.success("应用成功")
          this.getData()
        }
      })
    },
    // 清除
    handleCleanupClick(scope) {
      scope.row.isSet = !scope.row.isSet
    },
    // 行点击
    tableRowClick(row, rowIndex) {
      this.locationId = row.locationId
      this.rowIndex = rowIndex
      this.isSel()
      //!this.isNoProduct && this.currentRowId == 0
      if (!this.isNoProduct) {
        this.$message.error("请完成当前保存或取消保存！")
      } else {
        this.currentRowId = row.id
        this.addTitle = "保存"
        this.showDiscard = true
        this.isRowClick = true
        if (!this.isNoProduct) {
          this.tableData.splice(this.tableData.length - 1, 1)
        }
        this.tableData.map((item, index) => {
          if (index === rowIndex) {
            item.isEdit = false
            item.editable = true
          } else {
            item.isEdit = true
          }
        })
        this.differenceAmount = row.differenceAmount
        this.amount = row.amount
        this.productId = row.productId
        this.operationId = row.operationId
      }
    },
    // 搜索
    getList(val) {
      this.keyword = val
      this.pagerOptions.currPage = 1
      this.getData()
    },
    // 选择位置方法
    selLocationClick(item, prop) {
      console.log(item, prop)
      this.locationId = item.value
    },
    // 选择产品方法
    async selProductClick(value, item) {
          console.log("看看返回",this.tableData)
      if (value === "product") {
        this.productId = item.productId
        await getLocationProductAmount({
          locationId:this.locationId,
          productId:this.productId
        }).then((res)=>{
          if(res&&res.code===200){
            this.tableData[0].amount=res.data?res.data.amount:0
          }
        })
      }
    },
    // 获取当前时间
    currentTime() {
      return currentTime()
    }
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped>
::v-deep {
  .el-table {
    border-top-left-radius: 12px;
    border-top-right-radius: 12px;
    overflow: auto;
  }
}
</style>
